@@ -879,7 +879,7 @@ func (t *Tester) Main(args ...string) int {
 	// Reset the logger, for tests where t.Main is called multiple times.
 	G.Logger.errors = 0
 	G.Logger.warnings = 0
-	G.Logger.logged = OnceStringSlices{}
+	G.Logger.logged = OncePerStringSlice{}
 
 	argv := []string{"pkglint"}
 	for _, arg := range args {
@@ -1145,7 +1145,7 @@ func (t *Tester) Output() string {
 	t.stdout.Reset()
 	t.stderr.Reset()
 	if G.isUsable() {
-		G.Logger.logged = OnceStringSlices{}
+		G.Logger.logged = OncePerStringSlice{}
 		if G.Logger.out != nil { // Necessary because Main resets the G variable.
 			G.Logger.out.state = 0 // Prevent an empty line at the beginning of the next output.
 			G.Logger.err.state = 0
