@@ -13,7 +13,7 @@ type MkAssignChecker struct {
 }
 
 func NewMkAssignChecker(mkLine *MkLine, mkLines *MkLines) *MkAssignChecker {
-	return &MkAssignChecker{MkLine: mkLine, MkLines: mkLines}
+	return &MkAssignChecker{mkLine, mkLines}
 }
 
 func (ck *MkAssignChecker) check() {
@@ -81,7 +81,7 @@ func (ck *MkAssignChecker) checkLeftNotUsed() {
 		return
 	}
 
-	if !ck.MkLines.once.FirstTimeSlice("defined but not used: ", varname) {
+	if !ck.MkLines.warnedAboutDefinedNotUsed.FirstTime(varname) {
 		return
 	}
 
@@ -160,7 +160,7 @@ func (ck *MkAssignChecker) checkLeftBsdPrefs() {
 		return
 	}
 
-	if !ck.MkLines.once.FirstTime("include bsd.prefs.mk before using ?=") {
+	if !ck.MkLines.warnedAboutDefaultAssignment.FirstTime() {
 		return
 	}
 	mkline.Warnf("Include \"../../mk/bsd.prefs.mk\" before using \"?=\".")
