@@ -40,8 +40,8 @@ func (s *Suite) Test_MkCondChecker_Check(c *check.C) {
 
 	test(
 		".if ${A} != ${B}",
-		"WARN: filename.mk:4: A is used but not defined.",
-		"WARN: filename.mk:4: B is used but not defined.")
+		"WARN: filename.mk:4: Variable \"A\" is used but not defined.",
+		"WARN: filename.mk:4: Variable \"B\" is used but not defined.")
 
 	test(".if ${HOMEPAGE} == \"mailto:someone@example.org\"",
 		"WARN: filename.mk:4: \"mailto:someone@example.org\" is not a valid URL.",
@@ -95,16 +95,16 @@ func (s *Suite) Test_MkCondChecker_Check(c *check.C) {
 	// to the comparison operator, and not to one of its arguments.
 	test(".if !${VAR} == value",
 		"WARN: filename.mk:4: The ! should use parentheses or be merged into the comparison operator.",
-		"WARN: filename.mk:4: VAR is used but not defined.")
+		"WARN: filename.mk:4: Variable \"VAR\" is used but not defined.")
 
 	// Doesn't occur in practice since this string can never be empty.
 	test(".if !\"${VAR}str\"",
-		"WARN: filename.mk:4: VAR is used but not defined.")
+		"WARN: filename.mk:4: Variable \"VAR\" is used but not defined.")
 
 	// Doesn't occur in practice since !${VAR} && !${VAR2} is more idiomatic.
 	test(".if !\"${VAR}${VAR2}\"",
-		"WARN: filename.mk:4: VAR is used but not defined.",
-		"WARN: filename.mk:4: VAR2 is used but not defined.")
+		"WARN: filename.mk:4: Variable \"VAR\" is used but not defined.",
+		"WARN: filename.mk:4: Variable \"VAR2\" is used but not defined.")
 
 	// Just for code coverage; always evaluates to true.
 	test(".if \"string\"",
@@ -115,27 +115,32 @@ func (s *Suite) Test_MkCondChecker_Check(c *check.C) {
 		nil...)
 
 	test(".if ${VAR}",
-		"WARN: filename.mk:4: VAR is used but not defined.")
+		"WARN: filename.mk:4: Variable \"VAR\" is used but not defined.")
 
 	test(".if ${VAR} == 3",
-		"WARN: filename.mk:4: VAR is used but not defined.")
+		"WARN: filename.mk:4: Variable \"VAR\" is used but not defined.")
 
 	test(".if \"value\" == ${VAR}",
-		"WARN: filename.mk:4: VAR is used but not defined.")
+		"WARN: filename.mk:4: Variable \"VAR\" is used but not defined.")
 
 	test(".if ${MASTER_SITES:Mftp://*} == \"ftp://netbsd.org/\"",
-		// XXX: duplicate diagnostic, see MkParser.MkCond.
-		"WARN: filename.mk:4: Invalid variable modifier \"//*\" for \"MASTER_SITES\".",
 		"WARN: filename.mk:4: Invalid variable modifier \"//*\" for \"MASTER_SITES\".",
 		"WARN: filename.mk:4: \"ftp\" is not a valid URL.",
 		"WARN: filename.mk:4: MASTER_SITES should not be used at load time in any file.")
 
 	test(".if !",
-		"WARN: filename.mk:4: Invalid condition, unrecognized part: \"\".")
+		"WARN: filename.mk:4: Invalid condition, unrecognized part \"\".")
 
 	// TODO: There should be another error for the '.elif' outside '.if'.
 	test(".elif 0",
 		"ERROR: filename.mk:5: Unmatched .endif.")
+
+	// TODO: Warn about the ambiguous $f.
+	test(".if empty(PERDITION_SKIP_DISABLE:M$f)",
+		"WARN: filename.mk:4: Variable \"PERDITION_SKIP_DISABLE\" is used but not defined.")
+
+	test(".if !empty(:!${ECHO} yes | ${TOOLS_PLATFORM.m4} -s 2>/dev/null||${ECHO}!)",
+		nil...)
 }
 
 func (s *Suite) Test_MkCondChecker_Check__tracing(c *check.C) {
@@ -151,7 +156,7 @@ func (s *Suite) Test_MkCondChecker_Check__tracing(c *check.C) {
 
 	t.CheckOutputLinesMatching(`^WARN|checkCompare`,
 		"TRACE: 1 2   checkCompareExprStr ${VAR:Mpattern1:Mpattern2} == comparison",
-		"WARN: filename.mk:2: VAR is used but not defined.")
+		"WARN: filename.mk:2: Variable \"VAR\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkCondChecker_Check__comparison_with_shell_command(c *check.C) {
@@ -479,6 +484,14 @@ func (s *Suite) Test_MkCondChecker_checkAnd(c *check.C) {
 	test(
 		".if defined(VAR) || !empty(VAR:Mpattern)",
 		nil...)
+
+	// Since the second condition is not 'empty', the defined-empty
+	// redundancy does not apply.
+	// There is an undetected contradiction, though, as the two
+	// conditions are opposite.
+	test(
+		".if defined(VAR) && !defined(VAR)",
+		nil...)
 }
 
 func (s *Suite) Test_MkCondChecker_checkNotEmpty(c *check.C) {
@@ -684,7 +697,7 @@ func (s *Suite) Test_MkCondChecker_checkCompare(c *check.C) {
 	// As of July 2019, pkglint doesn't have specific checks for comparing
 	// variables to numbers.
 	test(".if ${VAR} > 0",
-		"WARN: filename.mk:1: VAR is used but not defined.")
+		"WARN: filename.mk:1: Variable \"VAR\" is used but not defined.")
 
 	// For string comparisons, the checks from vartypecheck.go are
 	// performed.
@@ -700,7 +713,7 @@ func (s *Suite) Test_MkCondChecker_checkCompare(c *check.C) {
 
 	// This is a shorthand for defined(VAR), but it is not used in practice.
 	test(".if VAR",
-		"WARN: filename.mk:1: Invalid condition, unrecognized part: \"VAR\".")
+		"WARN: filename.mk:1: Invalid condition, unrecognized part \"VAR\".")
 
 	// Calling a function with braces instead of parentheses is syntactically
 	// invalid. Pkglint is stricter than bmake in this situation.
@@ -712,7 +725,7 @@ func (s *Suite) Test_MkCondChecker_checkCompare(c *check.C) {
 	//
 	// See https://mail-index.netbsd.org/tech-pkg/2019/07/07/msg021539.html
 	test(".if !empty{VAR}",
-		"WARN: filename.mk:1: Invalid condition, unrecognized part: \"empty{VAR}\".")
+		"WARN: filename.mk:1: Invalid condition, unrecognized part \"empty{VAR}\".")
 }
 
 func (s *Suite) Test_MkCondChecker_checkCompareExprStr__no_tracing(c *check.C) {
@@ -747,7 +760,7 @@ func (s *Suite) Test_MkCondChecker_checkCompareWithNum(c *check.C) {
 	t.CheckOutputLines(
 		"WARN: filename.mk:4: Numeric comparison > 6.5.",
 		"ERROR: filename.mk:4: _PYTHON_VERSION must not be compared numerically.",
-		"WARN: filename.mk:4: _PYTHON_VERSION is used but not defined.")
+		"WARN: filename.mk:4: Variable \"_PYTHON_VERSION\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkCondChecker_checkCompareWithNumVersion(c *check.C) {
@@ -783,6 +796,9 @@ func (s *Suite) Test_MkCondChecker_checkCompareWithNumPython(c *check.C) {
 		".if ${_PYTHON_VERSION} < 38",
 		".elif ${_PYTHON_VERSION} < 310",
 		".elif \"\" < 310",
+		".elif ${_PYTHON_VERSION} < 3.10",
+		".elif ${_PYTHON_VERSION} == 310",
+		".elif ${_PYTHON_VERSION} != 311",
 		".endif")
 
 	mklines.Check()
@@ -959,13 +975,18 @@ func (s *Suite) Test_MkCondChecker_collectFacts(c *check.C) {
 		".      endif",
 		".    endif",
 		".  endif",
+		".endif",
+		"",
+		".ifndef VARNAME",
 		".endif")
 	var facts []VarFact
 
 	mklines.ForEach(func(mkline *MkLine) {
-		ck := NewMkCondChecker(mkline, mklines)
-		if mkline.NeedsCond() {
-			facts = append(facts, ck.collectFacts(mkline)...)
+		if mkline.IsDirective() {
+			ck := NewMkCondChecker(mkline, mklines)
+			if mkline.NeedsCond() {
+				facts = append(facts, ck.collectFacts(mkline)...)
+			}
 		}
 	})
 
