@@ -909,17 +909,16 @@ outer:
 }
 
 func (mkline *MkLine) checkFileGlobbing(ch int, str string) {
-	if !(ch == '*' || ch == '?' || ch == '[') {
-		return
-	}
-
-	chStr := string(rune(ch))
-	if !mkline.once.FirstTimeSlice("unintended file globbing", chStr) {
+	switch {
+	case ch == '*' && mkline.warnedAboutFileGlobbingAsterisk.FirstTime():
+	case ch == '?' && mkline.warnedAboutFileGlobbingQuestion.FirstTime():
+	case ch == '[' && mkline.warnedAboutFileGlobbingBracket.FirstTime():
+	default:
 		return
 	}
 
 	mkline.Warnf("The %q in the word %q may lead to unintended file globbing.",
-		chStr, str)
+		string(rune(ch)), str)
 	mkline.Explain(
 		"To fix this, enclose the word in \"double\" or 'single' quotes.")
 }
