@@ -303,7 +303,7 @@ func (s *Suite) Test_CheckLinesOptionsMk(c *check.C) {
 	CheckLinesOptionsMk(mklines, "")
 
 	t.CheckOutputLines(
-		"WARN: ~/category/package/options.mk:6: l is used but not defined.",
+		"WARN: ~/category/package/options.mk:6: Variable \"l\" is used but not defined.",
 		"WARN: ~/category/package/options.mk:18: Undocumented option \"undeclared\".",
 		"WARN: ~/category/package/options.mk:21: "+
 			"The positive branch of the .if/.else should be the one where the option is set.",
@@ -378,7 +378,7 @@ func (s *Suite) Test_CheckLinesOptionsMk__malformed_condition(c *check.C) {
 	CheckLinesOptionsMk(mklines, "")
 
 	t.CheckOutputLines(
-		"WARN: category/package/options.mk:15: Invalid condition, unrecognized part: \"${OPSYS} == 'Darwin'\".")
+		"WARN: category/package/options.mk:15: Invalid condition, unrecognized part \"${OPSYS} == 'Darwin'\".")
 }
 
 func (s *Suite) Test_CheckLinesOptionsMk__PLIST_VARS_based_on_PKG_SUPPORTED_OPTIONS(c *check.C) {
@@ -387,7 +387,8 @@ func (s *Suite) Test_CheckLinesOptionsMk__PLIST_VARS_based_on_PKG_SUPPORTED_OPTI
 	t.SetUpOption("one", "")
 	t.SetUpOption("two", "")
 	t.SetUpOption("three", "")
-	t.SetUpPackage("category/package")
+	t.SetUpPackage("category/package",
+		".include \"options.mk\"")
 	t.CreateFileLines("mk/bsd.options.mk")
 	t.SetUpFileMkLines("category/package/options.mk",
 		MkCvsID,
@@ -433,7 +434,8 @@ func (s *Suite) Test_CheckLinesOptionsMk__PLIST_VARS_based_on_groups(c *check.C)
 	t.SetUpOption("opt-two", "")
 	t.SetUpOption("req-one", "")
 	t.SetUpOption("req-two", "")
-	t.SetUpPackage("category/package")
+	t.SetUpPackage("category/package",
+		".include \"options.mk\"")
 	t.CreateFileLines("mk/bsd.options.mk")
 	t.SetUpFileMkLines("category/package/options.mk",
 		MkCvsID,
@@ -776,6 +778,6 @@ func (s *Suite) Test_OptionsLinesChecker_handleLowerCondition__foreign_variable(
 	G.Check(t.File("category/package"))
 
 	t.CheckOutputLines(
-		"WARN: ~/category/package/options.mk:8: OTHER_VARIABLE is used but not defined.",
+		"WARN: ~/category/package/options.mk:8: Variable \"OTHER_VARIABLE\" is used but not defined.",
 		"WARN: ~/category/package/options.mk:4: Option \"opt\" should be handled below in an .if block.")
 }
