@@ -81,8 +81,8 @@ type Package struct {
 
 	IgnoreMissingPatches bool // In distinfo, don't warn about patches that cannot be found.
 
-	warnedAboutConditionalInclusion OnceStringSlices
-	checkedPolicyUpdateLimited      OnceBool
+	warnedAboutConditionalInclusion OncePerStringSlice
+	checkedPolicyUpdateLimited      Once
 
 	// Contains the basenames of the distfiles that are mentioned in distinfo,
 	// for example "package-1.0.tar.gz", even if that file is in a DIST_SUBDIR.
@@ -385,7 +385,7 @@ func (pkg *Package) loadIncluded(mkline *MkLine, includingFile CurrPath) (includ
 	}
 
 	// XXX: Depending on the current working directory, the filename
-	// that is added to pkg.included differs. When running pkglint
+	// that is added to pkg.included differs. Running pkglint
 	// from the pkgsrc root directory resolves relative paths, while
 	// running pkglint from the package directory keeps the "../.."
 	// prefix.
@@ -554,10 +554,10 @@ func (pkg *Package) loadPlistDirs(plistFilename CurrPath) {
 		make(map[RelPath]*PlistLine),
 		make(map[RelPath]*PlistLine),
 		"",
-		OnceBool{},
-		OnceBool{},
-		OnceBool{},
-		OnceStrings{},
+		Once{},
+		Once{},
+		Once{},
+		OncePerString{},
 		false}
 	plistLines := ck.Load(lines)
 
@@ -1057,7 +1057,7 @@ func (pkg *Package) checkGnuConfigureUseLanguages() {
 // USE_LANGUAGES, as these would be ignored by the pkgsrc infrastructure.
 func (pkg *Package) checkUseLanguagesCompilerMk(mklines *MkLines) {
 
-	var seen OnceStrings
+	var seen OncePerString
 
 	handleVarassign := func(mkline *MkLine) {
 		if mkline.Varname() != "USE_LANGUAGES" {
@@ -1098,13 +1098,14 @@ func (pkg *Package) checkUseLanguagesCompilerMk(mklines *MkLines) {
 // GNU autotools or another build system, before being migrated to Meson.
 func (pkg *Package) checkMeson(mklines *MkLines) {
 
-	if pkg.Includes("../../devel/meson/build.mk") == nil {
+	mkline := pkg.Includes("../../devel/meson/build.mk")
+	if mkline == nil {
 		return
 	}
 
 	pkg.checkMesonGnuMake(mklines)
 	pkg.checkMesonConfigureArgs()
-	pkg.checkMesonPython(mklines)
+	pkg.checkMesonPython(mklines, mkline)
 }
 
 func (pkg *Package) checkMesonGnuMake(mklines *MkLines) {
@@ -1134,11 +1135,14 @@ func (pkg *Package) checkMesonConfigureArgs() {
 		"CONFIGURE_ARGS are typically not needed anymore.")
 }
 
-func (pkg *Package) checkMesonPython(mklines *MkLines) {
+func (pkg *Package) checkMesonPython(mklines *MkLines, mkline *MkLine) {
 
 	if mklines.allVars.IsDefined("PYTHON_FOR_BUILD_ONLY") {
 		return
 	}
+	if mklines.allVars.IsDefined("REPLACE_PYTHON") {
+		return
+	}
 
 	for path := range pkg.unconditionalIncludes {
 		if path.ContainsPath("lang/python") && !path.AsPath().HasSuffixPath("lang/python/tool.mk") {
@@ -1148,7 +1152,6 @@ func (pkg *Package) checkMesonPython(mklines *MkLines) {
 	return
 
 warn:
-	mkline := NewLineWhole(pkg.File("."))
 	mkline.Warnf("Meson packages usually need Python only at build time.")
 	mkline.Explain(
 		"The Meson build system is implemented in Python,",
@@ -1615,7 +1618,7 @@ func (pkg *Package) checkIncludeConditionally(mkline *MkLine, indentation *Inden
 
 	if indentation.IsConditional() {
 		if other := pkg.unconditionalIncludes[key]; other != nil {
-			if !pkg.warnedAboutConditionalInclusion.FirstTimeSlice(mkline.String(), other.String()) {
+			if !pkg.warnedAboutConditionalInclusion.FirstTime(mkline.String(), other.String()) {
 				return
 			}
 
@@ -1631,7 +1634,7 @@ func (pkg *Package) checkIncludeConditionally(mkline *MkLine, indentation *Inden
 
 	} else {
 		if other := pkg.conditionalIncludes[key]; other != nil {
-			if !pkg.warnedAboutConditionalInclusion.FirstTimeSlice(other.String(), mkline.String()) {
+			if !pkg.warnedAboutConditionalInclusion.FirstTime(other.String(), mkline.String()) {
 				return
 			}
 
@@ -1766,7 +1769,7 @@ func NewPlistContent() PlistContent {
 
 // IncludedMap remembers which files the package Makefile has included,
 // including indirect files.
-// See OnceStrings.
+// See OncePerString.
 type IncludedMap struct {
 	m     map[PackagePath]struct{}
 	Trace bool
