@@ -52,9 +52,8 @@ type Pkglint struct {
 	fileCache *FileCache
 	interner  StringInterner
 
-	// cwd is the absolute path to the current working
-	// directory. It is used for speeding up Relpath and abspath.
-	// There is no other use for it.
+	// cwd is the absolute path to the current working directory.
+	// It is used exclusively for speeding up Relpath and abspath.
 	cwd CurrPath
 
 	InterPackage InterPackage
@@ -163,7 +162,7 @@ func (p *Pkglint) prepareMainLoop() {
 		// If the first argument to pkglint is not inside a pkgsrc tree,
 		// pkglint doesn't know where to load the infrastructure files from.
 		if isFile {
-			// Allow this mode nevertheless, for checking the basic syntax
+			// Allow this mode, nevertheless, for checking the basic syntax
 			// and for formatting individual makefiles outside pkgsrc.
 		} else {
 			G.Logger.TechFatalf(firstDir, "Must be inside a pkgsrc tree.")
@@ -247,9 +246,7 @@ func (p *Pkglint) ParseCommandLine(args []string) int {
 }
 
 // Check checks a directory entry, which can be a regular file,
-// a directory or a symlink (only allowed for the working directory).
-//
-// This is the method that is called for each command line argument.
+// a directory, or a symlink (only allowed for the working directory).
 //
 // It sets up all the global state (infrastructure, wip) for accurately
 // classifying the entry.
@@ -478,62 +475,11 @@ func CheckLinesDescr(lines *Lines) {
 	SaveAutofixChanges(lines)
 }
 
-func CheckLinesMessage(lines *Lines, pkg *Package) {
-	if trace.Tracing {
-		defer trace.Call(lines.Filename)()
-	}
-
-	// For now, skip all checks when the MESSAGE may be built from multiple
-	// files.
-	//
-	// If the need arises, some of these checks may be activated again, but
-	// that requires more sophisticated code.
-	if pkg != nil && pkg.vars.IsDefined("MESSAGE_SRC") {
-		return
-	}
-
-	explanation := func() []string {
-		return []string{
-			"A MESSAGE file should consist of a header line, having 75 \"=\"",
-			"characters, followed by a line containing only the CVS Id, then an",
-			"empty line, your text and finally the footer line, which is the",
-			"same as the header line."}
-	}
-
-	if lines.Len() < 3 {
-		line := lines.LastLine()
-		line.Warnf("File too short.")
-		line.Explain(explanation()...)
-		return
-	}
-
-	hline := "==========================================================================="
-	if line := lines.Lines[0]; line.Text != hline {
-		fix := line.Autofix()
-		fix.Warnf("Expected a line of exactly 75 \"=\" characters.")
-		fix.Explain(explanation()...)
-		fix.InsertAbove(hline)
-		fix.Apply()
-		lines.CheckCvsID(0, ``, "")
-	} else {
-		lines.CheckCvsID(1, ``, "")
-	}
-	for _, line := range lines.Lines {
-		ck := LineChecker{line}
-		ck.CheckLength(80)
-		ck.CheckTrailingWhitespace()
-		ck.CheckValidCharacters()
-	}
-	if lastLine := lines.LastLine(); lastLine.Text != hline {
-		fix := lastLine.Autofix()
-		fix.Warnf("Expected a line of exactly 75 \"=\" characters.")
-		fix.Explain(explanation()...)
-		fix.InsertBelow(hline)
-		fix.Apply()
-	}
-	CheckLinesTrailingEmptyLines(lines)
-
-	SaveAutofixChanges(lines)
+func CheckFileMessage(filename CurrPath) {
+	line := NewLineWhole(filename)
+	line.Errorf("MESSAGE files are obsolete.")
+	line.Explain(
+		seeGuide("Files affecting the binary package", "components.optional.bin"))
 }
 
 func CheckFileMk(filename CurrPath, pkg *Package) {
@@ -558,7 +504,7 @@ func CheckFileMk(filename CurrPath, pkg *Package) {
 }
 
 // checkReg checks the given regular file.
-// depth is 3 for files in the package directory, and 4 or more for files
+// The depth is 3 for files in a package directory, and 4 or more for files
 // deeper in the directory hierarchy, such as in files/ or patches/.
 func (p *Pkglint) checkReg(filename CurrPath, basename RelPath, depth int, pkg *Package) {
 
@@ -615,9 +561,7 @@ func (p *Pkglint) checkReg(filename CurrPath, basename RelPath, depth int, pkg *
 		CheckFileOther(filename)
 
 	case basename.HasPrefixText("MESSAGE"):
-		if lines := Load(filename, NotEmpty|LogErrors); lines != nil {
-			CheckLinesMessage(lines, pkg)
-		}
+		CheckFileMessage(filename)
 
 	case basename == "options.mk":
 		if mklines := LoadMk(filename, pkg, NotEmpty|LogErrors); mklines != nil {
@@ -728,14 +672,14 @@ func (p *Pkglint) checkExecutable(filename CurrPath, mode os.FileMode) {
 }
 
 func CheckLinesTrailingEmptyLines(lines *Lines) {
-	max := lines.Len()
+	n := lines.Len()
 
-	last := max
+	last := n
 	for last > 1 && lines.Lines[last-1].Text == "" {
 		last--
 	}
 
-	if last != max {
+	if last != n {
 		lines.Lines[last].Notef("Trailing empty lines.")
 	}
 }
