@@ -408,7 +408,7 @@ func (ck *ShellLineChecker) checkSetE(list *MkShList, index int) {
 	}
 
 	line := ck.mkline.Line
-	if !line.once.FirstTime("switch to set -e") {
+	if !line.warnedAboutSetE.FirstTime() {
 		return
 	}
 
